.. _cli:

Command-line interface
======================

.. toctree::
   :maxdepth: 1
   :caption: Available commands:

   cli-commands/main
   cli-commands/optimize-rasters
   cli-commands/ingest
   cli-commands/serve
   cli-commands/connect
